OC.L10N.register(
    "core",
    {
    "Please select a file." : "Selecteer een bestand.",
    "File is too big" : "Bestand te groot",
    "Invalid file provided" : "Ongeldig bestand opgegeven",
    "No image or file provided" : "Geen afbeelding of bestand opgegeven",
    "Unknown filetype" : "Onbekend bestandsformaat",
    "Invalid image" : "Ongeldige afbeelding",
    "An error occurred. Please contact your admin." : "Er trad een fout op. Neem contact op met uw beheerder.",
    "No temporary profile picture available, try again" : "Geen tijdelijke profielafbeelding beschikbaar. Probeer het opnieuw",
    "No crop data provided" : "Geen bijsnijdingsgegevens opgegeven",
    "No valid crop data provided" : "Geen geldige bijsnijdingsgegevens opgegeven",
    "Crop is not square" : "Bijsnijding is niet vierkant",
    "Couldn't reset password because the token is invalid" : "Kon het wachtwoord niet herstellen, omdat het token ongeldig is",
    "Couldn't reset password because the token is expired" : "Kon het wachtwoord niet herstellen, omdat het token verlopen is",
    "Couldn't send reset email. Please make sure your username is correct." : "Kon e-mail niet versturen. Verifieer of uw gebruikersnaam correct is.",
    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "Kon geen herstel e-mail versturen, omdat er geen e-mailadres bekend is bij deze gebruikersnaam. Neem contact op met uw beheerder.",
    "%s password reset" : "%s wachtwoord reset",
    "Couldn't send reset email. Please contact your administrator." : "Kon herstel e-mail niet versturen. Neem contact op met uw beheerder.",
    "Error loading tags" : "Fout bij laden tags",
    "Tag already exists" : "Tag bestaat al",
    "Error deleting tag(s)" : "Fout bij verwijderen tag(s)",
    "Error tagging" : "Fout bij taggen",
    "Error untagging" : "Fout bij ont-taggen",
    "Error favoriting" : "Fout bij favoriet maken",
    "Error unfavoriting" : "Fout bij verwijderen favorietstatus",
    "Couldn't send mail to following users: %s " : "Kon geen e-mail sturen aan de volgende gebruikers: %s",
    "Preparing update" : "Update voorbereiden",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair warning: " : "Reparatiewaarschuwing:",
    "Repair error: " : "Reparatiefout:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Gebruik de commandoregel updater, omdat automatische update is uitgeschakeld in config.php.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Controleren tabel %s",
    "Turned on maintenance mode" : "Onderhoudsmodus ingeschakeld",
    "Turned off maintenance mode" : "Onderhoudsmodus uitgeschakeld",
    "Maintenance mode is kept active" : "Onderhoudsmodus blijft actief",
    "Updating database schema" : "Database schema aan het updaten",
    "Updated database" : "Database bijgewerkt",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Controleert of het database schema geüpdatet kan worden (dit kan lang duren afhankelijk van de grootte van de de database)",
    "Checked database schema update" : "Database schema-update gecontroleerd",
    "Checking updates of apps" : "Controleert of er updates voor apps zijn",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Controleert of het database schema voor %s geüpdatet kan worden ( dit kan lang duren afhankelijk van de grootte van de database )",
    "Checked database schema update for apps" : "Database schema-update voor apps gecontroleerd",
    "Updated \"%s\" to %s" : "Bijgewerkt \"%s\" naar %s",
    "Set log level to debug" : "Logniveau instellen op debug",
    "Reset log level" : "Terugzetten logniveau",
    "Starting code integrity check" : "Starten code betrouwbaarheidscontrole",
    "Finished code integrity check" : "Gereed met code betrouwbaarheidscontrole",
    "%s (3rdparty)" : "%s (3rdparty)",
    "%s (incompatible)" : "%s (incompatibel)",
    "Following apps have been disabled: %s" : "De volgende apps zijn gedeactiveerd: %s",
    "Already up to date" : "Al bijgewerkt",
    "Sunday" : "zondag",
    "Monday" : "maandag",
    "Tuesday" : "dinsdag",
    "Wednesday" : "woensdag",
    "Thursday" : "donderdag",
    "Friday" : "vrijdag",
    "Saturday" : "zaterdag",
    "Sun." : "Zon.",
    "Mon." : "Maa.",
    "Tue." : "Din.",
    "Wed." : "Woe.",
    "Thu." : "Do.",
    "Fri." : "Vri.",
    "Sat." : "Zat.",
    "Su" : "Zo",
    "Mo" : "Ma",
    "Tu" : "Di",
    "We" : "Wo",
    "Th" : "Do",
    "Fr" : "Vr",
    "Sa" : "Za",
    "January" : "januari",
    "February" : "februari",
    "March" : "maart",
    "April" : "april",
    "May" : "mei",
    "June" : "juni",
    "July" : "juli",
    "August" : "augustus",
    "September" : "september",
    "October" : "oktober",
    "November" : "november",
    "December" : "december",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Maa.",
    "Apr." : "Apr.",
    "May." : "Mei.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dec.",
    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Er traden problemen op tijdens de code betrouwbaarheidscontrole. Meer informatie…</a>",
    "Settings" : "Instellingen",
    "Problem loading page, reloading in 5 seconds" : "Kan de pagina niet laden, verversen in 5 seconden",
    "Saving..." : "Opslaan",
    "Dismiss" : "Terzijde leggen",
    "seconds ago" : "seconden geleden",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "De link om uw wachtwoord te herstellen is per e-mail naar u verstuurd. Als u dit bericht niet binnen redelijke tijd hebt ontvangen, controleer dan uw spammap. <br>Als het daar niet in zit, neem dan contact op met uw beheerder.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Uw bestanden zijn versleuteld. Als u de herstelsleutel niet hebt geactiveerd, is er geen mogelijk om uw gegevens terug te krijgen nadat uw wachtwoord is hersteld. <br>Als u niet weet wat u moet doen, neem dan eerst contact op met uw beheerder. <br>Wilt u echt verder gaan?",
    "I know what I'm doing" : "Ik weet wat ik doe",
    "Password can not be changed. Please contact your administrator." : "Het wachtwoord kan niet worden gewijzigd. Neem contact op met uw beheerder.",
    "No" : "Nee",
    "Yes" : "Ja",
    "Choose" : "Kies",
    "Error loading file picker template: {error}" : "Fout bij laden bestandenselecteur sjabloon: {error}",
    "Ok" : "Ok",
    "Error loading message template: {error}" : "Fout bij laden berichtensjabloon: {error}",
    "read-only" : "Alleen lezen",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} bestandsconflict","{count} bestandsconflicten"],
    "One file conflict" : "Een bestandsconflict",
    "New Files" : "Nieuwe bestanden",
    "Already existing files" : "Al aanwezige bestanden",
    "Which files do you want to keep?" : "Welke bestanden wilt u bewaren?",
    "If you select both versions, the copied file will have a number added to its name." : "Als u beide versies selecteerde, zal het gekopieerde bestand een nummer aan de naam toegevoegd krijgen.",
    "Cancel" : "Annuleer",
    "Continue" : "Verder",
    "(all selected)" : "(alles geselecteerd)",
    "({count} selected)" : "({count} geselecteerd)",
    "Error loading file exists template" : "Fout bij laden bestand bestaat al sjabloon",
    "Very weak password" : "Zeer zwak wachtwoord",
    "Weak password" : "Zwak wachtwoord",
    "So-so password" : "Matig wachtwoord",
    "Good password" : "Goed wachtwoord",
    "Strong password" : "Sterk wachtwoord",
    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Uw webserver is nog niet goed ingesteld voor bestandssynchronisatie, omdat de WebDAV interface verstoord lijkt.",
    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Uw webserver is niet goed ingesteld om \"{url}\" te vinden. Meer informatie is te vinden in onze <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentatie</a>.",
    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Deze server heeft geen actieve internetverbinding. Dat betekent dat sommige functies, zoals aankoppelen van externe opslag, notificaties over updates of installatie van apps van 3e partijen niet werken. Ook het benaderen van bestanden vanaf een remote locatie en het versturen van notificatie e-mails kan mislukken. We adviseren om de internetverbinding voor deze server in te schakelen als u alle functies wilt gebruiken.",
    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Er is geen geheugencache geconfigureerd. Om de prestaties te verhogen kunt u de memcache configureren als die beschikbaar is. Meer informatie vind u in onze <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentatie</a>.",
    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "/dev/urandom is niet leesbaar door PHP, hetgeen wordt afgeraden wegens beveiligingsredenen. Meer informatie in onze <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentatie</a>.",
    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "U draait momenteel PHP {version}. We adviseren u om zo gauw uw distributie dat biedt, uw PHP versie bij te werken voor betere <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">prestaties en beveiliging geleverd door de PHP Group</a>.",
    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "De reverse proxy headerconfiguratie is onjuist, of u hebt toegang tot ownCloud via een vertrouwde proxy. Als u ownCloud niet via een vertrouwde proxy benadert, dan levert dan een beveiligingsrisico op, waardoor een aanvaller het IP-adres dat ownCloud ziet kan spoofen. Meer informatie is te vinden in onze <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentatie</a>.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached is geconfigureerd als gedistribueerde cache, maar de verkeerde PHP module \"memcache\" is geïnstalleerd. \\OC\\Memcache\\Memcached ondersteunt alleen \"memcached\" en niet \"memcache\". Zie de <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki over beide modules</a>.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Sommige bestanden kwamen niet door de code betrouwbaarheidscontrole. Meer informatie over het oplossen van dit probleem kan worden gevonden in onze <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentatie</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Lijst met ongeldige bestanden…</a> / <a href=\"{rescanEndpoint}\">Opnieuw…</a>)",
    "Error occurred while checking server setup" : "Een fout trad op bij checken serverconfiguratie",
    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Uw data folder en uw bestanden zijn waarschijnlijk vanaf het internet bereikbaar.  Het .htaccess-bestand werkt niet.  We raden ten zeerste aan aan om uw webserver zodanig te configureren, dat de datadirectory niet bereikbaar is vanaf het internet of om uw datadirectory te verplaatsen naar een locatie buiten de document root van de webserver.",
    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "De \"{header}\" HTTP header is niet overeenkomstig met \"{expected}\" geconfigureerd. Dit is een potentieel security of privacy risico en we adviseren om deze instelling te wijzigen.",
    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "De \"Strict-Transport-Security\" HTTP header is niet geconfigureerd met minimaal \"{seconds}\" seconden. Voor verbeterde beveiliging adviseren we HSTS in te schakelen zoals beschreven in onze<a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>.",
    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "U bent met deze site verbonden over HTTP. We adviseren met klem uw server zo te configureren dat HTTPS wordt vereist, zoals beschreven in onze <a href=\"{docUrl}\">security tips</a>.",
    "Shared" : "Gedeeld",
    "Shared with {recipients}" : "Gedeeld met {recipients}",
    "Error" : "Fout",
    "Error while sharing" : "Fout tijdens het delen",
    "Error while unsharing" : "Fout tijdens het stoppen met delen",
    "Error setting expiration date" : "Fout tijdens het instellen van de vervaldatum",
    "The public link will expire no later than {days} days after it is created" : "De openbare link vervalt niet eerder dan {days} dagen na het aanmaken",
    "Set expiration date" : "Stel vervaldatum in",
    "Expiration" : "Vervaltermijn",
    "Expiration date" : "Vervaldatum",
    "Choose a password for the public link" : "Kies een wachtwoord voor de openbare link",
    "Resharing is not allowed" : "Verder delen is niet toegestaan",
    "Share link" : "Deel link",
    "Link" : "Link",
    "Password protect" : "Wachtwoord beveiligd",
    "Password" : "Wachtwoord",
    "Allow editing" : "Toestaan bewerken",
    "Email link to person" : "E-mail link naar persoon",
    "Send" : "Versturen",
    "Sending ..." : "Versturen ...",
    "Email sent" : "E-mail verzonden",
    "Send link via email" : "Versturen link via e-mail",
    "Shared with you and the group {group} by {owner}" : "Gedeeld met u en de groep {group} door {owner}",
    "Shared with you by {owner}" : "Gedeeld met u door {owner}",
    "group" : "groep",
    "remote" : "extern",
    "notify by email" : "melden per e-mail",
    "Unshare" : "Stop met delen",
    "can share" : "kan delen",
    "can edit" : "kan wijzigen",
    "create" : "creëer",
    "change" : "wijzig",
    "delete" : "verwijderen",
    "access control" : "toegangscontrole",
    "Could not unshare" : "Kon delen niet ongedaan maken",
    "Share details could not be loaded for this item." : "Details van shares voor dit object konden niet worden geladen.",
    "No users or groups found for {search}" : "Geen gebruikers of groepen gevonden voor {search}",
    "No users found for {search}" : "Geen gebruikers gevonden voor {search}",
    "An error occurred. Please try again" : "Er trad een fout op. Probeer het opnieuw",
    "{sharee} (group)" : "{sharee} (groep)",
    "{sharee} (at {server})" : "{sharee} (op {server})",
    "{sharee} (remote)" : "{sharee} (extern)",
    "Share" : "Delen",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Delen met mensen op andere ownClouds via de syntax gebruikersnaam@voorbeeld.org/owncloud",
    "Share with users…" : "Delen met gebruikers...",
    "Share with users, groups or remote users…" : "Delen met gebruikers, groepen of externe gebruikers...",
    "Share with users or groups…" : "Delen met gebruikers of groepen...",
    "Share with users or remote users…" : "Delen met gebruikers of externe gebruikers...",
    "Error removing share" : "Fout bij verwijderen share",
    "Warning" : "Waarschuwing",
    "Error while sending notification" : "Fout bij versturen melding",
    "Non-existing tag #{tag}" : "Niet bestaande tag #{tag}",
    "restricted" : "beperkt",
    "invisible" : "onzichtbaar",
    "({scope})" : "({scope})",
    "Delete" : "Verwijder",
    "Rename" : "Naam wijzigen",
    "Collaborative tags" : "Meewerkende labels",
    "The object type is not specified." : "Het object type is niet gespecificeerd.",
    "Enter new" : "Opgeven nieuw",
    "Add" : "Toevoegen",
    "Edit tags" : "Bewerken tags",
    "Error loading dialog template: {error}" : "Fout bij laden dialoog sjabloon: {error}",
    "No tags selected for deletion." : "Geen tags geselecteerd voor verwijdering.",
    "unknown text" : "onbekende tekst",
    "Hello world!" : "Hallo wereld!",
    "sunny" : "zonnig",
    "Hello {name}, the weather is {weather}" : "Hallo {name}, het is hier {weather}",
    "Hello {name}" : "Hallo {name}",
    "new" : "nieuw",
    "_download %n file_::_download %n files_" : ["download %n bestand","download %n bestanden"],
    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "De update is bezig, deze pagina verlaten kan het updateproces in sommige omgevingen onderbreken.",
    "Updating to {version}" : "Aan het bijwerken naar {version}",
    "An error occurred." : "Er heeft zich een fout voorgedaan.",
    "Please reload the page." : "Herlaad deze pagina.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "De update was niet succesvol. Voor meer informatie <a href=\"{url}\">zie ons bericht op het forum</a> over dit probleem.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "De update is niet geslaagd. Meld dit probleem bij de <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>.",
    "The update was successful. There were warnings." : "De update is geslaagd. Er zijn wel waarschuwingen.",
    "The update was successful. Redirecting you to ownCloud now." : "De update is geslaagd. U wordt teruggeleid naar uw eigen ownCloud.",
    "Searching other places" : "Zoeken op andere plaatsen",
    "No search results in other folders" : "Geen zoekresultaten in andere mappen",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} zoekresultaat in een andere map","{count} zoekresultaten in andere mappen"],
    "Personal" : "Persoonlijk",
    "Users" : "Gebruikers",
    "Apps" : "Apps",
    "Admin" : "Beheerder",
    "Help" : "Help",
    "Access forbidden" : "Toegang verboden",
    "File not found" : "Bestand niet gevonden",
    "The specified document has not been found on the server." : "Het opgegeven document is niet gevonden op deze server.",
    "You can click here to return to %s." : "Klik hier om terug te keren naar %s.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Hallo,\n\n%s deelt %s met u.\nBekijk hier: %s\n\n",
    "The share will expire on %s." : "De share vervalt op %s.",
    "Cheers!" : "Proficiat!",
    "Internal Server Error" : "Interne serverfout",
    "The server encountered an internal error and was unable to complete your request." : "De server ontdekte een interne fout en kon uw aanvraag niet verder uitvoeren.",
    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Neem contact op mer de serverbeheerder als deze fout meerdere keren optreedt en neem de onderstaande technische details op in uw melding.",
    "More details can be found in the server log." : "Meer details in de serverlogging,",
    "Technical details" : "Technische details",
    "Remote Address: %s" : "Extern adres: %s",
    "Request ID: %s" : "Aanvraag ID: %s",
    "Type: %s" : "Type: %s",
    "Code: %s" : "Code: %s",
    "Message: %s" : "Boodschap: %s",
    "File: %s" : "Bestand: %s",
    "Line: %s" : "Regel: %s",
    "Trace" : "Trace",
    "Security warning" : "Beveiligingswaarschuwing",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Uw gegevensdirectory en bestanden zijn vermoedelijk bereikbaar vanaf het internet, omdat het .htaccess-bestand niet functioneert.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">documentation</a>." : "Bekijk de <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">documentatie</a> voor Informatie over het correct configureren van uw server.",
    "Create an <strong>admin account</strong>" : "Maak een <strong>beheerdersaccount</strong> aan",
    "Username" : "Gebruikersnaam",
    "Storage & database" : "Opslag & database",
    "Data folder" : "Gegevensmap",
    "Configure the database" : "Configureer de database",
    "Only %s is available." : "Alleen %s is beschikbaar.",
    "Install and activate additional PHP modules to choose other database types." : "Installeer en activeer aanvullende PHP modules om andere soorten databases te kiezen.",
    "For more details check out the documentation." : "Voor meer informatie wordt u verwezen naar de documentatie.",
    "Database user" : "Gebruiker database",
    "Database password" : "Wachtwoord database",
    "Database name" : "Naam database",
    "Database tablespace" : "Database tablespace",
    "Database host" : "Databaseserver",
    "Performance warning" : "Prestatiewaarschuwing",
    "SQLite will be used as database." : "SQLite wordt gebruikt als database.",
    "For larger installations we recommend to choose a different database backend." : "Voor grotere installaties adviseren we een andere database engine te kiezen.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Vooral wanneer de desktop client wordt gebruik voor bestandssynchronisatie wordt gebruik van sqlite afgeraden.",
    "Finish setup" : "Installatie afronden",
    "Finishing …" : "Afronden ...",
    "Need help?" : "Hulp nodig?",
    "See the documentation" : "Zie de documentatie",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hallo,<br><br>%s deelt <strong>%s</strong> met u.<br><a href=\"%s\">Bekijk hier!</a><br><br>",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Deze applicatie heeft JavaScript nodig. {linkstart}Activeer JavaScript{linkend} en ververs deze pagina.",
    "Log out" : "Afmelden",
    "Search" : "Zoeken",
    "Server side authentication failed!" : "Authenticatie bij de server mislukte!",
    "Please contact your administrator." : "Neem contact op met uw systeembeheerder.",
    "An internal error occurred." : "Er heeft zich een interne fout voorgedaan.",
    "Please try again or contact your administrator." : "Probeer het opnieuw of neem contact op met uw beheerder.",
    "Username or email" : "Gebruikersnaam of e-mail",
    "Log in" : "Meld u aan",
    "Wrong password. Reset it?" : "Onjuist wachtwoord. Resetten?",
    "Wrong password." : "Onjuist wachtwoord.",
    "Stay logged in" : "Ingelogd blijven",
    "Alternative Logins" : "Alternatieve inlogs",
    "Use the following link to reset your password: {link}" : "Gebruik de volgende link om uw wachtwoord te resetten: {link}",
    "New password" : "Nieuw wachtwoord",
    "New Password" : "Nieuw wachtwoord",
    "Reset password" : "Reset wachtwoord",
    "This ownCloud instance is currently in single user mode." : "Deze ownCloud werkt momenteel in enkele gebruiker modus.",
    "This means only administrators can use the instance." : "Dat betekent dat alleen beheerders deze installatie kunnen gebruiken.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Neem contact op met uw systeembeheerder als deze melding aanhoudt of onverwacht verscheen.",
    "Thank you for your patience." : "Bedankt voor uw geduld.",
    "Two-step verification" : "Twee-staps verificatie",
    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "Aanvullende beveiliging is ingeschakeld voor uw account. Log in met een tweede factor.",
    "Cancel login" : "Inlog annuleren",
    "Please authenticate using the selected factor." : "Log in met de geselecteerde factor.",
    "An error occured while verifying the token" : "Er trad een fout op bij het verifiëren van het token",
    "You are accessing the server from an untrusted domain." : "U benadert de server vanaf een niet vertrouwd domein.",
    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Neem contact op met uw beheerder. Als u de beheerder van deze service bent, configureer dan de \"trusted_domains\" instelling in config/config.php. Een voorbeeldconfiguratie is gegeven in config/config.sample.php.",
    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Afhankelijk van uw configuratie zou u als beheerder ook de onderstaande knop kunnen gebruiken om dit domein te vertrouwen.",
    "Add \"%s\" as trusted domain" : "\"%s\" toevoegen als vertrouwd domein",
    "App update required" : "Bijwerken App vereist",
    "%s will be updated to version %s" : "%s wordt bijgewerkt naar versie %s",
    "These apps will be updated:" : "Deze apps worden bijgewerkt:",
    "These incompatible apps will be disabled:" : "De volgende incompatibele apps worden uitgeschakeld:",
    "The theme %s has been disabled." : "Het thema %s is uitgeschakeld.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Let erop dat de database, de config map en de data map zijn gebackupped voordat u verder gaat.",
    "Start update" : "Begin de update",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Om time-outs tijdens grotere installaties te voorkomen, kunt u in plaats hiervan de volgende opdracht geven vanaf uw installatiedirectory:",
    "Detailed logs" : "Gedetailleerde logs",
    "Update needed" : "Update vereist",
    "Please use the command line updater because you have a big instance." : "Gebruik de commandoregel updater, omdat u een grote ownCloud hebt.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Voor hulp, lees de <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentatie</a>.",
    "This %s instance is currently in maintenance mode, which may take a while." : "Deze %s staat momenteel in de onderhoudsstand, dat kan enige tijd duren.",
    "This page will refresh itself when the %s instance is available again." : "Deze pagina wordt ververst als de %s-installatie weer beschikbaar is."
},
"nplurals=2; plural=(n != 1);");
